@@ -10,8 +10,8 @@ use constant FORWARD => 1;
 our ($VERSION, @EXPORT_OK, %EXPORT_TAGS);
 my @subs;
 
-$VERSION = '0.20_01';
-@subs = qw(rhombus rhombus_letter rhombus_digit);
+$VERSION = '0.21_01';
+@subs = qw(rhombus rhombus_letter rhombus_digit rhombus_random);
 @EXPORT_OK = @subs;
 %EXPORT_TAGS = ('all' => [ @subs ]);
 
@@ -27,7 +27,7 @@ sub _draw_rhombus
 {
     my ($mode, $lines, $char, $case, $fillup, $forward) = @_;
 
-    my ($is_letter, $is_digit) = ($mode eq 'letter', $mode eq 'digit');
+    my ($is_letter, $is_digit, $is_random) = ($mode eq 'letter', $mode eq 'digit', $mode eq 'random');
 
     my %alter = (
         lower => sub { lc $_[0] },
@@ -35,6 +35,9 @@ sub _draw_rhombus
     );
     $char = $alter{$case}->($char) if $is_letter;
 
+    my @chars = map chr, (48..57, 65..90, 97..122);
+    $char = $chars[int(rand(@chars))] unless defined $char;
+
     $lines++ if $lines % 2 == 0;
 
     my ($line, $repeat, $rhombus);
@@ -55,6 +58,9 @@ sub _draw_rhombus
         elsif ($is_digit) {
             $char = $forward ? $char + 1 : $char - 1;
         }
+        elsif ($is_random) {
+            $char = $chars[int(rand(@chars))];
+        }
 
         if ($is_letter && $char !~ /[a-zA-Z]/) {
             $char = $alter{$case}->($forward ? 'a' : 'z');
@@ -94,6 +100,16 @@ sub rhombus_digit
     return _draw_rhombus('digit', $lines, $digit, undef, $fillup, $forward);
 }
 
+sub rhombus_random
+{
+    my %opts = @_;
+
+    my $lines  = $get_opt->(\%opts, 'lines',  qr/^\d+$/, LINES);
+    my $fillup = $get_opt->(\%opts, 'fillup', qr/^\S$/,  FILLUP);
+
+    return _draw_rhombus('random', $lines, undef, undef, $fillup, undef);
+}
+
 1;
 __END__
 
@@ -202,11 +218,36 @@ Forward digit enumeration. Defaults to boolean C<1>.
 
 =back
 
+=head2 rhombus_random
+
+Draws a rhombus with random letters/digits and returns it as a string.
+
+If no option value is supplied or if it is invalid, then a default
+will be silently assumed (omitting all options will return a rhombus
+of 25 lines).
+
+Given that the specified number of lines is even, it will be
+incremented to satisfy the requirement of being an odd number.
+
+Options:
+
+=over 4
+
+=item * C<lines>
+
+Number of lines to be printed. Defaults to 25.
+
+=item * C<fillup>
+
+The fillup character. Defaults to C<+>.
+
+=back
+
 =head1 EXPORT
 
 =head2 Functions
 
-C<rhombus(), rhombus_letter(), rhombus_digit()> are exportable.
+C<rhombus(), rhombus_letter(), rhombus_digit(), rhombus_random()> are exportable.
 
 =head2 Tags
 
